(function ($, Drupal) {
  "use strict";
  //Drupal behaviours
  Drupal.behaviors.video_toolbox = {
    attach: function (context, settings) {
      // Only execute code once. Without this wrapping function it would execute
      // as many times as called.
      $('main', context).once('video_toolbox').each(function () {

        // Configure element attributes as needed.
        $('.video-frame').each(function (i, obj) {
          if ($(this).siblings('.video-controls')) {
            $(this).removeAttr('controls');
          }
        });
        $('video').attr('oncontextmenu', 'return false');

        // Give CSS properties.
        $('.fa-pause').css('display', 'none');

        // Add the configured color to the Video Player elements
        $('.video-controls').css('background', settings.videoToolBox.control_color).click(function (e) {
          // Stops Forms from being sent.
          e.preventDefault();
        });
        $('.video-bar').css('background', settings.videoToolBox.bar_color)
        $('.video-inner').css('background', settings.videoToolBox.progress_color)
        $('.video-timeline').css('border-color', settings.videoToolBox.progress_color)
        $('.video-player .video-controls button').css('color', settings.videoToolBox.button_color)


        // VIDEO CONTROL FUNCTIONS.
        // Update the progress bar.
        $('.video-frame').on('timeupdate', function () {
          let videoFrame = $(this).get(0);
          let videoControls = $(this).siblings('.video-controls');
          let curr = (videoFrame.currentTime / videoFrame.duration) * 100;
          if (videoFrame.ended) {
            videoControls.find(".fa-play").css('display', 'block');
            videoControls.find(".fa-pause").css('display', 'none');
          }
          videoControls.find('.video-inner').css('width', `${curr}%`);
        })

        // Play or Pause video (Pause button).
        $('.video-play-btn').click(function (e) {
          // Select the parent HTML5 video from the DOM.
          let video = $(this).parents('.video-controls').siblings('.video-frame').get(0);
          // Condition when to play a video.
          if (video.paused) {
            $(this).find('.fa-play').css('display', 'none');
            $(this).find('.fa-pause').css('display', 'block');
            video.play();
          }
          else {
            $(this).find('.fa-play').css('display', 'block');
            $(this).find('.fa-pause').css('display', 'none');
            video.pause();
          }
        });

        // Play or Pause video (Video Frame).
        $('.video-frame').click(function (e) {
          // Select the parent HTML5 video from the DOM.
          let video = $(this).get(0);
          // Get .video-controls sibling element.
          let controls = $(this).siblings('.video-controls');
          // Condition when to play a video.
          if (video.paused) {
            controls.find('.fa-play').css('display', 'none');
            controls.find('.fa-pause').css('display', 'block');
            video.play();
          }
          else {
            controls.find('.fa-play').css('display', 'block');
            controls.find('.fa-pause').css('display', 'none');
            video.pause();
          }
        });

        // Rewind the video.
        $('.video-backward-btn').click(function (e) {
          // Select the parent HTML5 video from the DOM.
          let video = $(this).parents('.video-controls').siblings('.video-frame').get(0);
          video.currentTime = video.currentTime - ((video.duration / 100) * 5);
        });

        // Fast forward video.
        $('.video-forward-btn').click(function (e) {
          // Select the parent HTML5 video from the DOM.
          let video = $(this).parents('.video-controls').siblings('.video-frame').get(0);
          video.currentTime = video.currentTime + ((video.duration / 100) * 5);
        });

        // Trigger Fullscreen
        $('.video-expand-btn').click(function (e) {
          // Select the parent HTML5 video from the DOM.
          let video = $(this).parents('.video-controls').siblings('.video-frame').get(0);
          e.preventDefault()
          video.requestFullscreen()
        });

        // Go to specified part of the video.
        $('.video-bar').click(function (e) {
          // Select the parent HTML5 video from the DOM.
          let videoFrame = $(this).parents('.video-controls').siblings('.video-frame').get(0);

          // Get the target (.video-bar).
          const target = e.currentTarget;

          // Get the bounding rectangle of target.
          const rect = target.getBoundingClientRect();

          // Mouse position relative to bar, and bar width.
          const x = e.clientX - rect.left;
          const rectWidth = rect.width;

          // Get the percentage of the selection to find the selected time.
          let currSelectPer = ((x / rectWidth) * 100).toFixed(2);
          let currSelect = (currSelectPer / 100) * (videoFrame.duration);
          videoFrame.currentTime = currSelect;
        });
      });
    }
  };
})(jQuery, Drupal);
